\name{PerPosROCmin}
\alias{PerPosROCmin}
\alias{PerPosROC}
\alias{hivpos.gag}
\alias{hivneg.gag}
\alias{hivpos.pola}
\alias{hivneg.pola}
\alias{hivpos.polb}
\alias{hivneg.polb}
\title{Vaccine Research Center (VRC), NIH, Bethesda, MD data-Percentage
  Positives }
\description{

  Note: Percentage Positives = 100*(Percent Positives) of the stimulated
  sample based on the 99.9th percentile of the unstimulated distribution.
  
  For each sample/individual of the Interferon Gamma variable
  (cytokine repsonses), a 100*percent positive is defined as 100* the ratio
  of GAG stimulated cells greater than the 99.9th percentile of
  corresponding sample of unstimulated cells' (from the same given
  individual) distribution over the total number of GAG stimulated
  cells in the given sample from the individual.

  Thus, for a given individual, 100*Percent Positive = 100*k/n,
  where k is the number of stimulated cells >= 99.9th percentile of the
  corresponding distribution of the unstimulated cells of the same
  individual and n is the total number of stimulated cells in the
  sample.

  The following are the 100*(percent positives) for different peptide
  stimulations (GAG, PolA, or PolB) and different individuals
  (HIV positive & HIV negative).
  
  \item{hivpos.gag}{100*(Percent Positives) of the GAG stimulated cells from 29
    HIV positive individuals}
  \item{hivneg.gag}{100*(Percent Positives) of the GAG stimulated cells from 10
    HIV negative individuals}
  \item{hivpos.pola}{100*(Percent Positives) of the PolA stimulated cells from 29
    HIV positive individuals}
  \item{hivneg.pola}{100*(Percent Positives) of the PolA stimulated cells from 10
    HIV negative individuals }
  \item{hivpos.polb}{100*(Percent Positives) of the PolB stimulated cells from 29
    HIV positive individuals }
  \item{hivneg.polb}{100*(Percent Positives) of the PolB stimulated cells from 10
    HIV negative individuals  }
  
}
\usage{ data(PerPosROC)}
\format{Four numeric vectors }
\source{

  Cytokine reponse Table from Zoe Moodie PhD who obtained the
  percent positives from the data from the
  Vaccine Research Center (VRC), NIH, Bethesda, MD

  Also from the 'PerPosROC' data from the \pkg{rfcdorig} data package.
}
\examples{
   data(PerPosROCmin)
if (require(rflowcyt)){
## the example below comes from ROC.FCS function

#plotting the gag stimulated 100* percent positives
   if (interactive()==TRUE){
      GAG<-ROC.FCS(hivpos.gag, hivneg.gag)
#plotting the pola stimulated 100* percent positives
      POLA<-ROC.FCS(hivpos.pola, hivneg.pola, lineopt=2, colopt=2, overlay=TRUE)
#plotting the polb stimulated 100* percent positives
      POLB<-ROC.FCS(hivpos.polb, hivneg.polb, lineopt=4, colopt=3, overlay=TRUE)
      legend(0.7, 0.7, c("gag", "polA", "polB"), col = c(1,2,3), lty=c(1,2,4))
    }
} else {
cat("Installation of the rflowcyt package is needed to run the examples.", "\n\n")
}

}
\keyword{datasets}
